package sop_stage

import (
	"context"

	"wechat-api/ent/predicate"
	"wechat-api/ent/sopstage"
	"wechat-api/internal/svc"
	"wechat-api/internal/types"
	"wechat-api/internal/utils/dberrorhandler"

	"github.com/suyuan32/simple-admin-common/msg/errormsg"

	"github.com/suyuan32/simple-admin-common/utils/pointy"
	"github.com/zeromicro/go-zero/core/logx"
)

type GetSopStageListLogic struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
	logx.Logger
}

func NewGetSopStageListLogic(ctx context.Context, svcCtx *svc.ServiceContext) *GetSopStageListLogic {
	return &GetSopStageListLogic{
		ctx:    ctx,
		svcCtx: svcCtx,
		Logger: logx.WithContext(ctx),
	}
}

func (l *GetSopStageListLogic) GetSopStageList(req *types.SopStageListReq) (*types.SopStageListResp, error) {
	var predicates []predicate.SopStage
	if req.Name != nil {
		predicates = append(predicates, sopstage.NameContains(*req.Name))
	}
	data, err := l.svcCtx.DB.SopStage.Query().Where(predicates...).Page(l.ctx, req.Page, req.PageSize)

	if err != nil {
		return nil, dberrorhandler.DefaultEntError(l.Logger, err, req)
	}

	resp := &types.SopStageListResp{}
	resp.Msg = errormsg.Success
	resp.Data.Total = data.PageDetails.Total

	for _, v := range data.List {
		conditionList := make([]types.Condition, len(v.ConditionList))
		for i, condition := range v.ConditionList {
			conditionList[i] = types.Condition{
				Equal:       condition.Equal,
				LabelIdList: condition.LabelIdList,
			}
		}

		actionMessage := make([]types.Action, len(v.ActionMessage))
		for i, condition := range v.ActionMessage {
			actionMessage[i] = types.Action{
				Type:    condition.Type,
				Content: condition.Content,
			}
		}

		resp.Data.Data = append(resp.Data.Data,
			types.SopStageInfo{
				BaseIDInfo: types.BaseIDInfo{
					Id:        &v.ID,
					CreatedAt: pointy.GetPointer(v.CreatedAt.UnixMilli()),
					UpdatedAt: pointy.GetPointer(v.UpdatedAt.UnixMilli()),
				},
				Status:            &v.Status,
				TaskId:            &v.TaskID,
				Name:              &v.Name,
				ConditionType:     &v.ConditionType,
				ConditionOperator: &v.ConditionOperator,
				ConditionList:     conditionList,
				ActionMessage:     actionMessage,
				ActionLabel:       v.ActionLabel,
				IndexSort:         &v.IndexSort,
			})
	}

	return resp, nil
}
